@@ -34,4 +34,7 @@ impl Meter for NoOpMeter {
     }
     fn record_replicated_bytes(&self, _value: u64) {}
     fn record_replication_op(&self, _key: replication::ReplicationOpsKey) {}
+
+    fn set_shard_cache_gauge(&self, _value: i64) {}
+    fn record_shard_cache_eviction(&self) {}
 }
