@@ -36,6 +36,7 @@ pub mod providers;
 use std::net::{IpAddr, SocketAddr};
 use std::path::PathBuf;
 use std::sync::Arc;
+use std::time::Duration;
 
 use inner_settings::InnerSettings;
 pub use inner_settings::InnerSettingsBuilder;
@@ -89,12 +90,6 @@ impl Settings {
         self.inner.shards_path.clone()
     }
 
-    /// When shard lazy loading is enabled, reader and writer will try to load a
-    /// shard before using it. Otherwise, they'll load all shards at startup
-    pub fn lazy_loading(&self) -> bool {
-        self.inner.lazy_loading
-    }
-
     /// Maximum number of shards an index node will store
     pub fn max_shards_per_node(&self) -> usize {
         self.inner.max_shards_per_node
@@ -174,15 +169,15 @@ impl Settings {
     pub fn node_role(&self) -> NodeRole {
         self.inner.node_role
     }
-    pub fn replication_delay_seconds(&self) -> u64 {
-        self.inner.replication_delay_seconds
+    pub fn replication_delay(&self) -> Duration {
+        self.inner.replication_delay
     }
 
     pub fn replication_max_concurrency(&self) -> u64 {
         self.inner.replication_max_concurrency
     }
 
-    pub fn replication_healthy_delay(&self) -> u64 {
+    pub fn replication_healthy_delay(&self) -> Duration {
         self.inner.replication_healthy_delay
     }
 
@@ -220,7 +215,6 @@ mod tests {
     #[test]
     fn test_settings_with_custom_setter() {
         let settings = Settings::builder()
-            .without_lazy_loading()
             .hostname("localhost")
             .sentry_env("prod")
             .with_jaeger_enabled()
@@ -229,7 +223,6 @@ mod tests {
             .inner_build()
             .unwrap();
 
-        assert!(!settings.lazy_loading);
         assert!(
             Ok(settings.public_ip) == "127.0.0.1".parse()
                 || Ok(settings.public_ip) == "::1".parse()
