@@ -29,7 +29,7 @@ use nucliadb_core::protos::shard_created::{
 };
 use nucliadb_core::protos::{
     DocumentSearchRequest, DocumentSearchResponse, EdgeList, GetShardRequest,
-    ParagraphSearchRequest, ParagraphSearchResponse, RelatedEntities, RelationPrefixSearchRequest,
+    ParagraphSearchRequest, ParagraphSearchResponse, RelationPrefixSearchRequest,
     RelationSearchRequest, RelationSearchResponse, SearchRequest, SearchResponse, Shard, ShardFile,
     ShardFileChunk, ShardFileList, StreamRequest, SuggestFeatures, SuggestRequest, SuggestResponse,
     TypeList, VectorSearchRequest, VectorSearchResponse,
@@ -38,6 +38,9 @@ use nucliadb_core::query_planner::QueryPlan;
 use nucliadb_core::thread::*;
 use nucliadb_core::tracing::{self, *};
 use nucliadb_procs::measure;
+use nucliadb_protos::nodereader::{RelationNodeFilter, RelationPrefixSearchResponse};
+use nucliadb_protos::utils::relation_node::NodeType;
+use nucliadb_relations2::reader::HashedRelationNode;
 
 use crate::disk_structure::*;
 use crate::shards::metadata::ShardMetadata;
@@ -115,6 +118,7 @@ impl ShardReader {
         match self.document_service_version {
             0 => DocumentService::DocumentV0,
             1 => DocumentService::DocumentV1,
+            2 => DocumentService::DocumentV2,
             i => panic!("Unknown document version {i}"),
         }
     }
@@ -341,10 +345,12 @@ impl ShardReader {
                     .filter(|prefix| prefix.len() >= MIN_VIABLE_PREFIX_SUGGEST)
                     .cloned()
                     .map(|prefix| RelationSearchRequest {
-                        shard_id: String::default(), // REVIEW: really?
                         prefix: Some(RelationPrefixSearchRequest {
                             prefix,
-                            ..Default::default()
+                            node_filters: vec![RelationNodeFilter {
+                                node_type: NodeType::Entity.into(),
+                                ..Default::default()
+                            }],
                         }),
                         ..Default::default()
                     });
@@ -357,13 +363,12 @@ impl ShardReader {
                     .into_iter()
                     .flatten() // unwrap errors and continue with successful results
                     .flat_map(|response| response.prefix)
-                    .flat_map(|prefix_response| prefix_response.nodes.into_iter())
-                    .map(|node| node.value);
+                    .flat_map(|prefix_response| prefix_response.nodes.into_iter());
 
                 // remove duplicate entities
-                let mut seen = HashSet::new();
+                let mut seen: HashSet<HashedRelationNode> = HashSet::new();
                 let mut ent_result = entities.collect::<Vec<_>>();
-                ent_result.retain(|e| seen.insert(e.clone()));
+                ent_result.retain(|e| seen.insert(e.clone().into()));
 
                 ent_result
             };
@@ -398,10 +403,7 @@ impl ShardReader {
         };
 
         if let Some(entities) = entities {
-            response.entities = Some(RelatedEntities {
-                total: entities.len() as u32,
-                entities,
-            })
+            response.entity_results = Some(RelationPrefixSearchResponse { nodes: entities });
         }
 
         Ok(response)
