@@ -27,9 +27,10 @@ use nucliadb_core::protos as nucliadb_protos;
 use nucliadb_protos::prost_types::Timestamp;
 use nucliadb_protos::resource::ResourceStatus;
 use nucliadb_protos::{
-    IndexMetadata, IndexParagraph, IndexParagraphs, NewShardRequest, Resource, ResourceId,
-    SearchRequest, TextInformation, Timestamps, VectorSentence,
+    IndexMetadata, IndexParagraph, IndexParagraphs, NewShardRequest, ReleaseChannel, Resource,
+    ResourceId, SearchRequest, TextInformation, Timestamps, VectorSentence,
 };
+use rstest::*;
 use tonic::Request;
 use uuid::Uuid;
 
@@ -94,13 +95,17 @@ async fn populate(writer: &mut TestNodeWriter, shard_id: String, metadata: Index
         relations: vec![],
         vectors: HashMap::default(),
         vectors_to_delete: HashMap::default(),
+        ..Default::default()
     };
 
     writer.set_resource(resource).await.unwrap();
 }
 
+#[rstest]
 #[tokio::test]
-async fn test_date_range_search() -> Result<(), Box<dyn std::error::Error>> {
+async fn test_date_range_search(
+    #[values(ReleaseChannel::Stable, ReleaseChannel::Experimental)] release_channel: ReleaseChannel,
+) -> Result<(), Box<dyn std::error::Error>> {
     let base_time = Timestamp::default();
     let mut fixture = NodeFixture::new();
     fixture.with_writer().await?.with_reader().await?;
@@ -108,7 +113,10 @@ async fn test_date_range_search() -> Result<(), Box<dyn std::error::Error>> {
     let mut reader = fixture.reader_client();
 
     let new_shard_response = writer
-        .new_shard(Request::new(NewShardRequest::default()))
+        .new_shard(Request::new(NewShardRequest {
+            release_channel: release_channel.into(),
+            ..Default::default()
+        }))
         .await?;
     let shard_id = &new_shard_response.get_ref().id;
 
