@@ -157,7 +157,7 @@ async fn test_suggest_entities(
     // basic suggests
     expect_entities(
         &suggest_entities(&mut reader, &shard.id, "Ann").await,
-        &["Anastasia", "Anna", "Anthony"],
+        &["Anna", "Anthony"],
     );
 
     expect_entities(
@@ -203,10 +203,17 @@ async fn test_suggest_entities(
 
     // multiple words and result ordering
     let response = suggest_entities(&mut reader, &shard.id, "Solomon Isa").await;
-    assert!(response.entities.is_some());
-    assert_eq!(response.entities.as_ref().unwrap().total, 2);
-    assert!(response.entities.as_ref().unwrap().entities[0] == *"Solomon Islands");
-    assert!(response.entities.as_ref().unwrap().entities[1] == *"Israel");
+    assert!(response.entity_results.is_some());
+    assert_eq!(response.entity_results.as_ref().unwrap().nodes.len(), 2);
+    assert!(response.entity_results.as_ref().unwrap().nodes[0].value == *"Solomon Islands");
+    assert!(response.entity_results.as_ref().unwrap().nodes[1].value == *"Israel");
+
+    // Does not find resources by UUID prefix
+    let pap_uuid = &shard.resources["pap"];
+    expect_entities(
+        &suggest_entities(&mut reader, &shard.id, &pap_uuid[0..6]).await,
+        &[],
+    );
 
     Ok(())
 }
@@ -231,7 +238,7 @@ async fn test_suggest_features(
     let mut reader = node.reader_client();
 
     let response = suggest_paragraphs(&mut reader, &shard.id, "ann").await;
-    assert!(response.entities.is_none());
+    assert!(response.entity_results.is_none());
     expect_paragraphs(
         &response,
         &[(&shard.resources["little prince"], "/a/summary")],
@@ -240,7 +247,7 @@ async fn test_suggest_features(
     let response = suggest_entities(&mut reader, &shard.id, "ann").await;
     assert_eq!(response.total, 0);
     assert!(response.results.is_empty());
-    expect_entities(&response, &["Anastasia", "Anna", "Anthony"]);
+    expect_entities(&response, &["Anna", "Anthony"]);
 
     Ok(())
 }
@@ -351,20 +358,21 @@ async fn suggest_entities(
 }
 
 fn expect_entities(response: &SuggestResponse, expected: &[&str]) {
-    assert!(response.entities.is_some());
+    assert!(response.entity_results.is_some());
     assert_eq!(
-        response.entities.as_ref().unwrap().total as usize,
+        response.entity_results.as_ref().unwrap().nodes.len(),
         expected.len(),
         "Response entities don't match expected ones: {:?} != {:?}",
-        response.entities,
+        response.entity_results,
         expected,
     );
     for entity in expected {
         assert!(response
-            .entities
+            .entity_results
             .as_ref()
             .unwrap()
-            .entities
-            .contains(&entity.to_string()));
+            .nodes
+            .iter()
+            .any(|e| &e.value == entity));
     }
 }
