@@ -424,7 +424,7 @@ impl RelationsReaderService {
     }
 }
 
-struct HashedRelationNode(RelationNode);
+pub struct HashedRelationNode(pub RelationNode);
 
 impl From<HashedRelationNode> for RelationNode {
     fn from(val: HashedRelationNode) -> Self {
@@ -432,6 +432,12 @@ impl From<HashedRelationNode> for RelationNode {
     }
 }
 
+impl From<RelationNode> for HashedRelationNode {
+    fn from(val: RelationNode) -> Self {
+        HashedRelationNode(val)
+    }
+}
+
 impl Eq for HashedRelationNode {}
 impl PartialEq for HashedRelationNode {
     fn eq(&self, other: &Self) -> bool {
